Automated Project Initialization 🐍💚💙 
---
An automated setup for Django project with Tailwind. Handles all setup and configuration automatically.✨

<p align="left">
  <a href="https://skillicons.dev">
    <img src="https://skillicons.dev/icons?i=django,tailwindcss,python" />
  </a>
</p>

## Fork this Repository or just copy my code💙
- 👀 Before you dive in, make sure that you have Node.js, Git, and Python installed on your computer.


## Open your VSCode terminal.

Run the following script in your vscode terminal:
```bash
python automate_setup.py
```

## Open another VSCode terminal.

Navigate to the 'app' directory:
```bash
cd app
```

Start the development server:
```bash
python manage.py runserver
```

![Alt Text](img.png)


## Happy Coding!!
